@@ -97,6 +97,8 @@ static int execInFork(const char *cmd)
         exit(rc);
 }
 
+static char resBuffer[1024];
+
 static char *readResultsFile(int * count) 
 {
 	FILE *fp;
@@ -120,12 +122,16 @@ static char *readResultsFile(int * count)
 	}
     
     	char * fBuffer = NULL;
-    	fBuffer = calloc(fLen+1,1);
-        if (fBuffer == NULL) {
-        	logger("ERROR","no more memory!");
-		return NULL;
+        if (fLen < 1024) {	// try to avoid memory fragmentation
+        	fBuffer = resBuffer;
+                memset(fBuffer, 0, 1024);
+        } else {
+    		fBuffer = calloc(fLen+1,1);
+        	if (fBuffer == NULL) {
+        		logger("ERROR","no more memory!");
+			return NULL;
+        	}
         }
-    
 	(*count) = fread(fBuffer, sizeof(char), fLen, fp);
     	fclose(fp);
     
@@ -133,6 +139,14 @@ static char *readResultsFile(int * count)
 	return fBuffer;
 }
 
+static void freeResults(char * ptr) 
+{
+	logger("DEBUG","freeResults");
+	if (ptr != resBuffer) {
+        	logger("DEBUG","freeResults: free");
+        	free(ptr);
+        }
+}
 static char* substParams(const char* in, cmdParams *params) {
 
 
@@ -160,8 +174,6 @@ static char* substParams(const char* in, cmdParams *params) {
         int needSize = strlen(ptr)+1; 
         int nParams  = 0;
         while(ptr != NULL) {
-        	varData* var = NULL;
-                
                 papameterized = strstr(ptr, PARAM_START);   // $(
                 
                 if (papameterized == NULL) { // Just copy
@@ -202,15 +214,17 @@ static char* substParams(const char* in, cmdParams *params) {
                         	char * br = index(papameterized+2,')');
                         	pLen = (br == NULL ? 0 : br - papameterized - 2);
                         }
-                	
+			
+                	varData* var = NULL;
+
                         if ((var = searchVar(papameterized + 2, pLen)) != NULL) {
                 
                         	logger("DEBUG", "searchVar() OK");
                         
                 		needSize += (var == NULL ? 0 : var->size - strlen(var->name) - 3); 
         
-				//sprintf(tmp, "Add bytes: %d", (var->size - strlen(var->name) - 3));
-        			//logger("DEBUG",tmp);
+				sprintf(tmp, "Add bytes: %d", (int) (var->size - strlen(var->name) - 3));
+        			logger("DEBUG",tmp);
                                 
                                 ptr = papameterized + strlen(var->name) + 3;
                                 nParams++;
@@ -227,14 +241,13 @@ static char* substParams(const char* in, cmdParams *params) {
         papameterized = NULL;
         ptr = command;
         
-        //sprintf(tmp, "Allocate >%d< bytes for parametrized command", needSize);
-        //logger("DEBUG",tmp);
+        DEBUG2("Allocate >%d< bytes for parametrized command", needSize);
 
 	char* cmd  = (char*) calloc(needSize+1,1);
+	int  count = 0;
        
         while(ptr != NULL) {
         	DEBUG2("cur cmd >%s<", ptr);
-		varData* var = NULL;
 
                 papameterized = strstr(ptr, PARAM_START);   // $(
         
@@ -244,28 +257,32 @@ static char* substParams(const char* in, cmdParams *params) {
         
                 if (papameterized == NULL) { // Just copy
                 	logger("DEBUG", "no more parameters");
-                        strcat(cmd, ptr);
+                        strcpy(cmd+count, ptr);
                         break;
                 } else if(strncmp(papameterized+2,PARAM_CALLID,pc) == 0) {
                 	
                         *papameterized = '\0';
-                        
-                        strcat(cmd, ptr);		// First part
-                        strcat(cmd, callerId);		// Add params
+			
+                        strcpy(cmd+count, ptr);		// First part
+                        strcat(cmd+count, callerId);    // Add params
                 
+                        count += strlen(ptr) + strlen(callerId);
                         ptr = papameterized + pc + 2;
-                    
+		     
                 } else if (strncmp(papameterized + 2,PARAM_MODE,pm) == 0) {
                 	
                         *papameterized = '\0';
+                        char *m = getMode();
                        
-                        strcat(cmd, ptr); 		// First part
-                        strcat(cmd, getMode());		// Add params
+                        strcpy(cmd+count, ptr); 	// First part
+                        strcat(cmd+count, m);		// Add params
                                 
+                        count += strlen(ptr) + strlen(m);
                         ptr = papameterized + pm + 2;
+                        
                 
                 } else if (strncmp(papameterized + 2,PARAM_PARAM,pp) == 0) {
-                	// This is dirty trick to make Bemused commands like VOLM<volume> works
+                	// This is a trick to make Bemused commands like VOLM<volume> works
                         // also it is used in Java Client list handling
                 
                         *papameterized = '\0';
@@ -273,11 +290,15 @@ static char* substParams(const char* in, cmdParams *params) {
                         if (params == NULL) {   // value can be empty
                         	logger("WARNING", "No parameters supplied!");
 
-                        	strcat(cmd, PARAM_START);
-                        	strcat(cmd, PARAM_PARAM);
+                        	strcpy(cmd+count, PARAM_START);
+                        	strcat(cmd+count, PARAM_PARAM);
+                                
+                                count += strlen(PARAM_START) + strlen(PARAM_PARAM);
                         } else {
-                        	strcat(cmd, ptr);		// First part
-                        	strcat(cmd, params->value);	// Add params
+                        	strcpy(cmd+count, ptr);			// First part
+                        	strcat(cmd+count, params->value);	// Add params
+                                
+                                count += strlen(ptr) + strlen(params->value);
                 	}
                         ptr = papameterized + pp + 2;
 
@@ -289,11 +310,15 @@ static char* substParams(const char* in, cmdParams *params) {
                         if (params == NULL || params->index == NULL || params->index[0] == '\0') {
                         	logger("WARNING", "No parameters supplied!");
 
-                        	strcat(cmd, PARAM_START);
-                        	strcat(cmd, PARAM_INDEX);
+                        	strcpy(cmd+count, PARAM_START);
+                        	strcat(cmd+count, PARAM_INDEX);
+                                
+                                count += strlen(PARAM_START) + strlen(PARAM_INDEX);
                         } else {
-                        	strcat(cmd, ptr);		// First part
-                        	strcat(cmd, params->index);	// Add params
+                        	strcpy(cmd+count, ptr);			// First part
+                        	strcat(cmd+count, params->index);	// Add params
+                               
+                                count += strlen(ptr) + strlen(params->index);
                         }
                         ptr = papameterized + pi + 2;
 
@@ -302,12 +327,14 @@ static char* substParams(const char* in, cmdParams *params) {
                         *papameterized = '\0';
                 
                         // First part
-                        strcat(cmd, ptr);
+                        strcpy(cmd+count, ptr);
+                	count += strlen(ptr);
 
                         // Add cfg. dir.
                         char *d;
                         if ((d = getCfgDir()) != NULL) {
-				strcat(cmd, d);
+				strcpy(cmd+count, d);
+                        	count += strlen(d);
                         }
                 
                         ptr = papameterized + pd + 2;
@@ -319,17 +346,19 @@ static char* substParams(const char* in, cmdParams *params) {
                         	char * br = index(papameterized+2,')');
                         	pLen = (br == NULL ? 0 : br - papameterized - 2);
                         }
-
+			
+			varData* var = NULL;
+			
                 	if ((var = searchVar(papameterized + 2, pLen)) != NULL) {
                         	logger("DEBUG", "substitute: searchVar() OK");
                            
                         	*papameterized = '\0'; 
-                                strcat(cmd, ptr);		// First part
-				
-				int lc = strlen(cmd);		// Umm...but if data is binary ?
+                                strcpy(cmd+count, ptr);		// First part
+				count += strlen(ptr);
 				
                                 if (var->size > 0) {
-                        		memcpy(cmd+lc, var->value, var->size);	// Add params
+                        		memcpy(cmd+count, var->value, var->size);	// Add params
+                                        count += var->size;
                         	}
                                 
         			DEBUG2("cmd var value >%s<", cmd);
@@ -339,13 +368,13 @@ static char* substParams(const char* in, cmdParams *params) {
                 	} else {    // Just copy
         			//sprintf(tmp, "Just copy >%s<", ptr);
         			//logger("DEBUG",tmp);
-                		strcat(cmd, ptr);
+                		strcpy(cmd+count, ptr);
+                                count += strlen(ptr);
                         	break;
                         }
                 }
         }
-        int cl = strlen(cmd);
-        DEBUG2("final cmd >%s< %d", cmd,cl);
+        DEBUG2("final cmd >%s< %d", cmd,count);
         
         free(command);
         
@@ -387,19 +416,19 @@ static int execSimpleCmd(const char *cmd, int toFile)
 }
 
 
-static int processSendCmd(cmdItem* ci)
+static int processSendCmd(char* sDescr)
 {
 	int ret = EXIT_OK;
 
         char all[MAXMAXLEN];
-        strncpy(all, ci->descr, MAXMAXLEN-1);
+        strncpy(all, sDescr, MAXMAXLEN-1);
 
         char *tag  = strtok(all, ",");
         if (tag == NULL) {
         	logger("DEBUG", "processSendCmd(): incorrect input (1)");                
         	return EXIT_NOK;
         }
-        if (strlen(ci->descr) <= strlen(tag) + 1) {   // Set(tag,) or Set(tag) without any value
+        if (strlen(sDescr) <= strlen(tag) + 1) {   // Set(tag,) or Set(tag) without any value
         	logger("DEBUG", "processSendCmd(): incorrect input (2)");                
                 return EXIT_NOK;
         }
@@ -692,7 +721,7 @@ static int makeCmd(cmdItem* ci, cmdParams* p)
 		        logger("DEBUG","Fails in setVar() (Make)");
 		}
                 
-                free(res);   res   = NULL;
+                freeResults(res); res = NULL;
 		free(sExec); sExec = NULL;
                
         } else if (strstr(ci->descr,MAKE_MODE) == ci->descr) {
@@ -880,16 +909,38 @@ int macroCmd(char *descr, char *exec, cmdParams* params)
         int runIt = 1;
         if (exec != NULL) {
         	int resLen = -1;
-        	char* res = executeCommand(exec, &resLen, params);
+                
+                if (exec && strstr(exec,"if_mode_at") == exec) {
+			if (serverMode != CLIENT_AT) {
+                        	runIt = 0; 
+                        }                   	
+                } else if (exec && strstr(exec,"if_mode_server") == exec) {
+			if (serverMode != SERVER_BT  &&
+                            serverMode != SERVER_TCP &&
+                            serverMode != SERVER_UX  &&
+                            serverMode != CLIENT_NOAT) {
+                        	runIt = 0; 
+                        }                   	
+                } else if (exec && strstr(exec,"if_mode_stdin") == exec) {
+			if (serverMode != SERVER_STDIN) {
+                        	runIt = 0; 
+                        }                   	
+                } else if (exec && strstr(exec,"if_mode_ilirc") == exec) {
+			if (serverMode != CLIENT_ILIRC) {
+                        	runIt = 0; 
+                        }                   	
+		} else {
+                
+        		char* res = executeCommand(exec, &resLen, params);
 		
-                //DEBUG2("exec value is %s",res ? res : "NULL");
-        	if (res == NULL) {
-                	runIt = 0;
-                } else {
-        		if (strcmp(res,"0") != 0 && strcmp(res,"0\n") != 0) {	// test return code $?
-        			runIt = 0;
-                        }
-                        free(res);
+        		if (res == NULL) {
+                		runIt = 0;
+                	} else {
+        			if (strcmp(res,"0") != 0 && strcmp(res,"0\n") != 0) {	// test return code $?
+        				runIt = 0;
+                        	}
+                        	freeResults(res);
+                	}
                 }	
         }
         
@@ -996,7 +1047,7 @@ static int execCmdAndGetResults(int type, cmdItem* ci, timerCmd* timer, cmdParam
         	}
   	}
         
-	free(res);
+	freeResults(res);
 	free(sDescr);
 
         //logger("INFO","execCmdAndGetResults finished");
@@ -1043,16 +1094,6 @@ static int processOneCommand(cmdItem* ci, cmdParams* p)
             	case ID_TIMER:   
                 	logger("INFO", "Command: Timer");
                 	return processTimerCmd(ci);
-
-            	case ID_SEND:
-                	logger("INFO", "Command: Send");
-                	if (serverMode == SERVER_BT || serverMode == SERVER_TCP || serverMode == SERVER_UX || serverMode == CLIENT_NOAT) {
-                        	ret = processSendCmd(ci);
-                        	if (ret != EXIT_OK) {
-                         		logger("DEBUG","Fails in processSendCmd()");
-                        	}
-                	}    
-                	return EXIT_OK;
                         
                 default:
                 	break;        
@@ -1130,6 +1171,16 @@ static int processOneCommand(cmdItem* ci, cmdParams* p)
                         ret = ckpdCmd(sDescr);
                  	break;
                  
+            	case ID_SEND:
+                	logger("INFO", "Command: Send");
+                	if (serverMode == SERVER_BT  || 
+                            serverMode == SERVER_TCP || 
+                            serverMode == SERVER_UX  ||  
+                            serverMode == CLIENT_NOAT) {
+                        	ret = processSendCmd(sDescr);
+                	}    
+                	break;
+                        
             	case ID_SET:          
                 	logger("INFO", "Command: Set");
                 	if (sDescr != NULL &&
