@@ -87,6 +87,11 @@ int getFrontEnd()
 	return conf.frontEnd;
 }
 
+int getHttp()
+{
+	return conf.http;
+}
+
 char* getCharset()
 {
 	return (conf.charset[0] == '\0' ? NULL : conf.charset);
@@ -582,6 +587,8 @@ void printParams()
 
 void printConf() 
 {
+        sprintf(tmp, "anyRemote %s", AR_VERSION);
+        logger("CFG", tmp);
 	printKeys   ();
 	printAliases();
 	printAlarms ();
