@@ -179,7 +179,7 @@ int openPort(char * portIn)
                 serverMode = SERVER_STDIN;
                 openStdin();
 
-        } else {
+        } else {	//if ((strPort = strstr(portIn, AT_DEVICE)) != NULL){
 
         	DEBUG2("Serial Client mode. Use device %s", portIn);
 
@@ -221,7 +221,9 @@ void createDataDir()
 // Then port will be closed from a forked child use 0
 void closePort(int final) 
 {
-	if (serverMode == SERVER_BT || serverMode == SERVER_TCP || serverMode == SERVER_UX) {
+	if (serverMode == SERVER_BT  || 
+            serverMode == SERVER_TCP || 
+            serverMode == SERVER_UX) {
          	closeSocketPort(serverMode);
         } else if (serverMode == CLIENT_ILIRC) {
         	if (unix_close_port() < 0) {
@@ -307,22 +309,7 @@ int main(int argc, char *argv[])
 	
         if (argv[1] && (strcmp(argv[1],"-h")==0 || strcmp(argv[1],"--help")==0)) {
 		 //Just print help and exit
-	         printf("Usage: anyremote [-h] [-f conf.file] [-s connect string] [-b baudrate] [-log] [-n] [-a] [-fe port]\n\n");
-	         printf(" -h|--help  print this help\n");
-	         printf(" -v|--version  print version of anyRemote\n");
-	         printf(" -f /path/to/file  specify configutational file\n");
-	         printf(" -s connect string,  possible values\n");
-	         printf("    /dev/rfcommX\n");
-	         printf("    bluetooth:<channel>\n");
-	         printf("    socket:<port>\n");
-	         printf("    ilirc:<AF_LOCAL socket file>\n");
-	         printf("    local:/dev/ircommX\n");
-	         printf("    stdin\n");
-	         printf(" -b    baudrate: specify baudrate, default is 19200\n");
-	         printf(" -log  print verbose logging information to $HOME/.anyRemote/anyremote.log\n");
-	         printf(" -n    do not send any AT+CKPD command to the phone\n");
-	         printf(" -a    reconnect automatically in case of connection failure\n");
-	         printf(" -fe <port> work as backend for GUI frontend. Use specified port to connect to frontend.\n\n");
+		 printHelp();
 	         exit(0);
         } else if (argv[1] && (strcmp(argv[1],"-v")==0 || strcmp(argv[1],"--version")==0)) {
 		printf("anyremote %s\n", AR_VERSION); 
@@ -331,7 +318,10 @@ int main(int argc, char *argv[])
 
         if (init_cfg(i<argc ? argv[++i] : NULL) != EXIT_OK) {
         	printf("Can not initialize configuration. Exiting.\n");
-                freeCfg();
+		
+		printHelp();
+                
+		freeCfg();
                 exit(1);
         }
                     
@@ -885,6 +875,9 @@ static void mainRoutine(void)
 				        printf("mainRoutine: Exec cmd on connect EXIT_ABORT/EXIT_DISCON \n");
 					return;
 		    		}
+				if (getHttp()) {
+					writeSocketConn("End();", 6);
+				}
 			}
 			
 			//printf("mainRoutine: connect OK\n");
@@ -958,6 +951,9 @@ static void mainRoutine(void)
 					ret = handle_command(answer);
 	    		
 	    				if (ret == EXIT_OK) {
+						if (getHttp()) {
+							writeSocketConn("End();", 6);
+						}
 	    		    			continue;
 	    				} else if (ret == EXIT_ABORT) {
 			   			 freeAndExit();  // Exit here
@@ -1073,9 +1069,9 @@ static void mainRoutine(void)
 
 		// Can't open port or it closed again
 		if (dmn || 
-		    serverMode == SERVER_BT  || 
-		    serverMode == SERVER_TCP ||
-		    serverMode == SERVER_UX  || 
+		    serverMode == SERVER_BT   || 
+		    serverMode == SERVER_TCP  ||
+		    serverMode == SERVER_UX   || 
 		    serverMode == CLIENT_NOAT || 
 		    ret == EXIT_DISCON) {
 		    
@@ -1197,7 +1193,16 @@ static int isBemusedCommand(char *cmdIn)
                         shift  = 5;
                 }
                 if (strncmp(cmd, "SLCT", 4) == 0) {
-                	handle = 1;
+		
+                	unsigned char bc1 = *((unsigned char*) (cmd + 4));
+                	unsigned char bc2 = *((unsigned char*) (cmd + 5));
+			
+			unsigned int ix = bc1*256+bc2;
+                        sprintf(paramValue, "%d",ix);
+			
+			DEBUG2("isBemusedCommand: SLCT parameter >%s<", paramValue);
+                	
+			handle = 1;
                         shift  = 6;
                 }
                 if (strncmp(cmd, "SEEK", 4) == 0)  {    
