@@ -84,7 +84,8 @@ CONF conf = { 0, 		// Log
 	      "",               // CMER OFF
 	      MODEL_DEFAULT,	// Model
 	      NULL,             // Cfg. dir
-	      -1};              // Front-end port                       
+	      -1,		// Front-end port    
+	      0};        	// Work with anyremote2html                         
 
 type_key* findExact(mode *mode, char *key)
 {
@@ -207,11 +208,13 @@ int parse_opts(int argc, char *argv[])
 			strcpy(conf.device, argv[++i]);
 		} else if ((strcmp(argv[i],"--baud")==0 || strcmp(argv[i],"-b")==0) && i+1<argc) {
 			conf.baudrate = setBaudrate(atoi(argv[++i]));
-		} else if ((strcmp(argv[i],"--noscreen")==0 || strcmp(argv[i],"-n")==0)) {
+		} else if (strcmp(argv[i],"--noscreen")==0 || strcmp(argv[i],"-n")==0) {
 			conf.screen = 0;
-		} else if ((strcmp(argv[i],"--autoconnect")==0 || strcmp(argv[i],"-a")==0)) {
+		} else if (strcmp(argv[i],"-http")==0) {
+			conf.http = 1;
+		} else if (strcmp(argv[i],"--autoconnect")==0 || strcmp(argv[i],"-a")==0) {
 			conf.autoConnect = 1;
-		} else if ((strcmp(argv[i],"-f")==0)) {
+		} else if (strcmp(argv[i],"-f")==0) {
 			++i;
 			continue;   // already processed this parameter
 		// -h and -v handled in main.c
@@ -641,6 +644,9 @@ static void storeMacroCmd(cmdItem* ci, char *cmd)
 	if (comma) {
         	*comma = '\0';
                 comma++;
+                while (comma && (*comma == ' ' || *comma == '\t')) {
+                	comma++;	
+                }
         }
 
 	deleteSpaces(&cmd,0);
