@@ -177,7 +177,7 @@ timerCmd* createTimer(cmdItem *ci)
         	logger("DEBUG", "createTimer(): timer already exists");                
                 return NULL;
         } 
-        timerCmd *tm = calloc(1,sizeof(timerCmd));
+        timerCmd *tm = calloc(sizeof(timerCmd),1);
 
         tm->ticks     = 0;
         tm->times     = 1;
@@ -354,10 +354,12 @@ static int addVar(const char *name, const char *val, int sz)
         varData * v = (varData *) calloc(sizeof(varData),1);
         v->name  = strdup(name);
 
-	if (sz > 0) {
-		v->value = calloc(1,sz);
+	if (sz > 0 && val != NULL) {
+		v->value = (char*) calloc(sz,1);
 		memcpy((void*)v->value, (const void *) val, sz); // can not user strdup() since val can contains binary data 
-        }
+        } else {
+		v->value = NULL;
+	}
         v->size = sz;
 	
         // Insert in head
@@ -382,11 +384,16 @@ int setVar(const char *name, const char *val, int sz)
         if (v == NULL) {		// Add variable if it not yet defined
         	return addVar(name, val, sz);
         }
-        
-        free(v->value); 	// Store new value in already defined variable
-        if (sz > 0) {
-		v->value = calloc(1,sz);
+	
+        // Store new value in already defined variable
+	if (v->value != NULL) {
+        	free(v->value);v->value = NULL;
+	}	 	
+        if (sz > 0 && val != NULL) {
+		v->value = (char*) calloc(sz,1);
 		memcpy((void*)v->value, (const void *) val, sz);
+	} else {
+		v->value = NULL;
 	}
         v->size = sz;
 
@@ -401,10 +408,12 @@ void freeVars()
         while (vars != NULL) {
         	vv   = vars;
                 vars = vars->next;
-                
+                vv->next = NULL;
+		 
         	free(vv->name); vv->name  = NULL;
-        	free(vv->value);vv->value = NULL;
-                
+		if (vv->value != NULL) {
+        		free(vv->value);vv->value = NULL;
+                }
                 free(vv);
         }
 }
@@ -422,6 +431,29 @@ extern type_key   *alarms;
 
 extern int  flushConf;
 
+void printHelp() 
+{
+	printf("Usage: anyremote [-h] [-f conf.file] [-s connect string] [-b baudrate] [-log] [-n] [-a] [-fe port]\n\n");
+	printf(" -h|--help  print this help\n");
+	printf(" -v|--version  print version of anyRemote\n");
+	printf(" -f /path/to/file  specify configutational file\n");
+	printf(" -s connect string,  possible values\n");
+	printf("    bluetooth:<channel> (Server mode - bluetooth connection)\n");
+	printf("    socket:<port>       (Server mode - TCP/IP connection)\n");
+	printf("    local:/dev/ircommX  (Server mode - IR connection)\n");
+	printf("    /dev/rfcomm#        (AT mode - bluetooth connection)\n");
+	printf("    /dev/ttyACM#        (AT mode - cable connection)\n");
+	printf("    /dev/ircomm#        (AT mode - IR connection)\n");
+	printf("    ilirc:<AF_LOCAL socket file> (use with inputlircd)\n");
+	printf("    stdin\n");
+	printf(" -log	print verbose logging information to $HOME/.anyRemote/anyremote.log\n");
+	printf(" -b	baudrate: specify baudrate, default is 19200\n");
+	printf(" -n	do not send any AT+CKPD command to the phone\n");
+	printf(" -a	reconnect automatically in case of connection failure\n");
+	printf(" -fe <port> work as backend for GUI frontend. Use specified port to connect to frontend.\n");
+	printf(" -http  tune work with anyremote2html\n\n");
+}
+
 int flushData() 
 {
 	//logger("DEBUG","flushData");
